``saltext-ufw``: Integrate Salt with Ufw
========================================

This Salt Extension provides modules for interacting with Ufw (Uncomplicated Firewall),
a frontend for managing a netfilter firewall designed to be easy to use.


References
----------
What's Salt?
    A remote execution, configuration management and automation system written in Python.
    See the `Salt guide <https://docs.saltproject.io/salt/user-guide/en/latest/topics/overview.html>`_ for details.

What's Ufw?
    A frontend for managing a netfilter firewall designed to be easy to use.
    See the `Ufw homepage <https://wiki.ubuntu.com/UncomplicatedFirewall>`_ for details.

Want to contribute?
    Come over to our `GitHub repo <https://github.com/voyvodov/saltext-ufw>`_.

Found a bug or missing a feature?
    File a report on our `issue tracker <https://github.com/voyvodov/saltext-ufw/issues>`_.

.. toctree::
  :maxdepth: 2
  :caption: Guides
  :hidden:

  topics/installation

.. toctree::
  :maxdepth: 2
  :caption: Provided Modules
  :hidden:

  ref/modules/index
  ref/states/index
  ref/utils/index

.. toctree::
  :maxdepth: 2
  :caption: Reference
  :hidden:

  changelog


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
